from setuptools import setup, find_packages

setup(
    name='socialagi',
    version='0.0.1',
    packages=find_packages(),
    author='Kevin Fischer',
    author_email='kevin@opensouls.org',
    description='A placeholder package for socialagi',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    package_dir={'': '.'},
)
